==> qtjambi-debuginfo-windows-x64-6.5.4.jar: sources/QtJambiGui/QSinglePointEvent_shell.h <==
#ifndef QSINGLEPOINTEVENT_SHELL_H
#define QSINGLEPOINTEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QSinglePointEvent_shell : public QSinglePointEvent, public QtJambiShellInterface
{
public:
    QSinglePointEvent_shell(qint32 type0, const QPointingDevice* dev1, const QEventPoint& point2, qint32 button3, qint32 buttons4, qint32 modifiers5, qint32 source6);
    QSinglePointEvent_shell(qint32 type0, const QPointingDevice* dev1, const QPointF& localPos2, const QPointF& scenePos3, const QPointF& globalPos4, qint32 button5, qint32 buttons6, qint32 modifiers7, qint32 source8 = Qt::MouseEventNotSynthesized);
    QSinglePointEvent_shell(const QSinglePointEvent& arg__1);
    ~QSinglePointEvent_shell() override;

    QSinglePointEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSinglePointEvent_access : public QSinglePointEvent
{
    void __qt_assign_cref_QSinglePointEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isBeginEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isEndEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setButton_cref_Qt_MouseButton(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint button0);
    void setDoubleClick_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean doubleClick0);
    jboolean doubleClick(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setInvertedScrolling_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean invertedScrolling0);
    jboolean invertedScrolling(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setButtons_cref_Qt_MouseButtons(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint buttons0);
    void setPhaseFlag_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jshort phaseFlag0);
    jshort phaseFlag(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setSourceFlag_cref_Qt_MouseEventSource(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint sourceFlag0);
    jint sourceFlag(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSINGLEPOINTEVENT_SHELL_H

==> qtjambi-debuginfo-windows-x64-6.6.3.jar: sources/QtJambiGui/QSinglePointEvent_shell.h <==
#ifndef QSINGLEPOINTEVENT_SHELL_H
#define QSINGLEPOINTEVENT_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qevent.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qcoreevent.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qpoint.h>
#include <QtGui/qeventpoint.h>
#include <QtGui/qinputdevice.h>
#include <QtGui/qpointingdevice.h>
#include <QtJambi/RegistryAPI>


class QSinglePointEvent_shell : public QSinglePointEvent, public QtJambiShellInterface
{
public:
    QSinglePointEvent_shell(qint32 type0, const QPointingDevice* dev1, const QEventPoint& point2, qint32 button3, qint32 buttons4, qint32 modifiers5, qint32 source6);
    QSinglePointEvent_shell(qint32 type0, const QPointingDevice* dev1, const QPointF& localPos2, const QPointF& scenePos3, const QPointF& globalPos4, qint32 button5, qint32 buttons6, qint32 modifiers7, qint32 source8 = Qt::MouseEventNotSynthesized);
    QSinglePointEvent_shell(const QSinglePointEvent& arg__1);
    ~QSinglePointEvent_shell() override;

    QSinglePointEvent* clone() const override;
    bool isBeginEvent() const override;
    bool isEndEvent() const override;
    bool isUpdateEvent() const override;
    void setAccepted(bool accepted0) override;
    void setTimestamp(quint64 timestamp0) override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QSinglePointEvent_access : public QSinglePointEvent
{
    void __qt_assign_cref_QSinglePointEvent(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID other0);
    jobject __qt_clone_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isBeginEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isEndEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    jboolean __qt_isUpdateEvent_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void setButton_cref_Qt_MouseButton(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint button0);
    void setDoubleClick_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean doubleClick0);
    jboolean doubleClick(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setInvertedScrolling_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jboolean invertedScrolling0);
    jboolean invertedScrolling(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setButtons_cref_Qt_MouseButtons(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint buttons0);
    void setPhaseFlag_quint16(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jshort phaseFlag0);
    jshort phaseFlag(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
    void setSourceFlag_cref_Qt_MouseEventSource(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, jint sourceFlag0);
    jint sourceFlag(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId);
};

#endif // QSINGLEPOINTEVENT_SHELL_H
